==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/tr/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Toplu varlık silmeyi onaylıyor musunuz?',
  'bulk_delete_help'	=> 'Toplu silme için aşağıdaki Varlıkları gözden geçirin. Silindikten sonra bu varlıkların geri yüklenebilir fakat atanmış olan herhangi bir kullanıcı ile ilişkili olmayacaktır.',
  'bulk_delete_warn'	=> ':asset_count adet varlığı düzenlemek üzeresiniz.',
	'bulk_update'		=> 'Demirbaşları Toplu Güncelle',
	'bulk_update_help'	=> 'Bu form birden çok demirbaşı tek seferde güncellemenizi sağlar. Lütfen sadece değiştirmek istediğiniz alanları doldurunuz. Değiştirilmesini istemediğiniz alanları boş bırakınız. ',
	'bulk_update_warn'	=> ':asset_count adet demirbaşı düzenlemek üzeresiniz.',
    'checkedout_to'		=> 'Çıkış Yapılmış Olan Kişi',
    'checkout_date'		=> 'Çıkış Tarihi',
    'checkin_date'		=> 'Giriş Tarihi',
    'checkout_to'		=> 'Çıkış Yapılacak Kişi',
    'cost'				=> 'Satın Alma Ücreti',
    'create'			=> 'Demirbaş Oluştur',
    'date'				=> 'Satın Alma Tarihi',
    'depreciation'	    => 'Amortisman',
    'depreciates_on'	=> 'Amortisman',
    'default_location'	=> 'Varsayılan Konum',
    'eol_date'			=> 'Ömür',
    'eol_rate'			=> 'Ömür Başarısı',
    'expected_checkin'  => 'Beklenen geri alma tarihi',
    'expires'			=> 'Son kullanma tarihi',
    'fully_depreciated'	=> 'Değeri tamamen düştü',
    'help_checkout'		=> 'Bu varlığı hemen atamak istiyorsanız Durum listesinden "Atanabilir" durumunu seçin. ',
    'mac_address'		=> 'MAC Adresi',
    'manufacturer'		=> 'Üretici',
    'model'				=> 'Model',
    'months'			=> 'ay',
    'name'				=> 'Demirbaş Adı',
    'notes'				=> 'Notlar',
    'order'				=> 'Sipariş Numarası',
    'qr'				=> 'QR Kod',
    'requestable'		=> 'Kullanıcılar bu demirbaşı talep edebilir',
    'select_statustype'	=> 'Durum Seçiniz',
    'serial'			=> 'Seri No',
    'status'			=> 'Durum',
    'tag'				=> 'Demirbaş Etiketi',
    'update'			=> 'Demirbaş Güncelle',
    'warranty'			=> 'Garanti',
		'warranty_expires'		=> 'Garanti Süresi Sona Erdi',
    'years'				=> 'yıl',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/tr/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Toplu varlık silmeyi onaylıyor musunuz?',
  'bulk_delete_help'	=> 'Toplu silme için aşağıdaki Varlıkları gözden geçirin. Silindikten sonra bu varlıkların geri yüklenebilir fakat atanmış olan herhangi bir kullanıcı ile ilişkili olmayacaktır.',
  'bulk_delete_warn'	=> ':asset_count adet varlığı düzenlemek üzeresiniz.',
    'bulk_update'		=> 'Demirbaşları Toplu Güncelle',
    'bulk_update_help'	=> 'Bu form birden çok demirbaşı tek seferde güncellemenizi sağlar. Lütfen sadece değiştirmek istediğiniz alanları doldurunuz. Değiştirilmesini istemediğiniz alanları boş bırakınız. ',
    'bulk_update_warn'	=> ':asset_count adet demirbaşı düzenlemek üzeresiniz.',
    'checkedout_to'		=> 'Çıkış Yapılmış Olan Kişi',
    'checkout_date'		=> 'Çıkış Tarihi',
    'checkin_date'		=> 'Giriş Tarihi',
    'checkout_to'		=> 'Çıkış Yapılacak Kişi',
    'cost'				=> 'Satın Alma Ücreti',
    'create'			=> 'Demirbaş Oluştur',
    'date'				=> 'Satın Alma Tarihi',
    'depreciation'	    => 'Amortisman',
    'depreciates_on'	=> 'Amortisman',
    'default_location'	=> 'Varsayılan Konum',
    'eol_date'			=> 'Ömür',
    'eol_rate'			=> 'Ömür Başarısı',
    'expected_checkin'  => 'Beklenen geri alma tarihi',
    'expires'			=> 'Son kullanma tarihi',
    'fully_depreciated'	=> 'Değeri tamamen düştü',
    'help_checkout'		=> 'Bu varlığı hemen atamak istiyorsanız Durum listesinden "Atanabilir" durumunu seçin. ',
    'mac_address'		=> 'MAC Adresi',
    'manufacturer'		=> 'Üretici',
    'model'				=> 'Model',
    'months'			=> 'ay',
    'name'				=> 'Demirbaş Adı',
    'notes'				=> 'Notlar',
    'order'				=> 'Sipariş Numarası',
    'qr'				=> 'QR Kod',
    'requestable'		=> 'Kullanıcılar bu demirbaşı talep edebilir',
    'select_statustype'	=> 'Durum Seçiniz',
    'serial'			=> 'Seri No',
    'status'			=> 'Durum',
    'tag'				=> 'Demirbaş Etiketi',
    'update'			=> 'Demirbaş Güncelle',
    'warranty'			=> 'Garanti',
        'warranty_expires'		=> 'Garanti Süresi Sona Erdi',
    'years'				=> 'yıl',
    'asset_location' => 'Varlık konumunu güncelle',
    'asset_location_update_default_current' => 'Varsayılan konumu ve gerçek konumu güncelle',
    'asset_location_update_default' => 'Sadece varsayılan konumu güncelle',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
